@@ -52,7 +52,7 @@
 #endif
 
 #include "dicto.h"
-#include "dicto-ui-marshal.h"
+#include "dicto-marshal.h"
 
 #define GST_TIME_TO_SECS(t) \
 	(gdouble) (((gdouble)(t)) / (gdouble) GST_SECOND) /* GST_SECOND should be 1e9 */
